@@ -81,6 +81,19 @@ class GenericTensor:
 		self.dirichlet_boundary = []
 		self.neumann_boundary = []
 
+	def set_velocity(self, id, value, is_dim_fixed=None):
+		"""set the velocity value for the sideset id. Note the value must be a vector in 2D or 3D depending on the problem"""
+		self.add_dirichlet_value(id, value, is_dim_fixed)
+
+	def set_displacement(self, id, value, is_dim_fixed=None):
+		"""set the displacement value for the sideset id. Note the value must be a vector in 2D or 3D depending on the problem"""
+		self.add_dirichlet_value(id, value, is_dim_fixed)
+
+	def set_force(self, id, value):
+		"""set the force value for the sideset id. Note the value must be a vector in 2D or 3D depending on the problem"""
+		self.add_neumann_value(id, value)
+
+
 	def add_dirichlet_value(self, id, value, is_dirichlet_dim=None):
 		"""add the Dirichlet value value for the sideset id. Note the value must be a vector in 2D or 3D depending on the problem. is_dirichlet_dim is a vector of boolean specifying which dimentions are fixed."""
 		assert(len(value) == 3 or len(value) == 2)
